@@ -6,7 +6,6 @@ from typing_extensions import Annotated, get_args, get_origin
 
 from .exceptions import MultipleStrawberryArgumentsError, UnsupportedTypeError
 from .scalars import is_scalar
-from .types.type_resolver import resolve_type
 from .types.types import ArgumentDefinition, undefined
 from .utils.str_converters import to_camel_case
 
@@ -62,7 +61,10 @@ def get_arguments_from_annotations(
 
         arguments.append(argument_definition)
 
-        resolve_type(argument_definition)
+        # Deferred to prevent import cycles
+        from .types.type_resolver import _resolve_type
+
+        _resolve_type(argument_definition)
 
     return arguments
 
@@ -110,8 +112,10 @@ def convert_argument(value: Any, argument_definition: ArgumentDefinition) -> Any
         kwargs = {}
 
         for field in argument_type._type_definition.fields:
-            if field.name in value:
-                kwargs[field.origin_name] = convert_argument(value[field.name], field)
+            if field.graphql_name in value:
+                kwargs[field.python_name] = convert_argument(
+                    value[field.graphql_name], field
+                )
 
         return argument_type(**kwargs)
 
