@@ -5,6 +5,7 @@ from typing import Any, Dict, Optional
 
 from django.core.exceptions import SuspiciousOperation
 from django.http import Http404, HttpRequest, HttpResponseNotAllowed, JsonResponse
+from django.http.response import HttpResponse
 from django.template import RequestContext, Template
 from django.template.exceptions import TemplateDoesNotExist
 from django.template.loader import render_to_string
@@ -23,6 +24,13 @@ from ..schema import BaseSchema
 from .context import StrawberryDjangoContext
 
 
+class TemporalHttpResponse(JsonResponse):
+    status_code = None
+
+    def __init__(self) -> None:
+        super().__init__({})
+
+
 class BaseView(View):
     graphiql = True
     schema: Optional[BaseSchema] = None
@@ -49,7 +57,10 @@ class BaseView(View):
         return "text/html" in request.META.get("HTTP_ACCEPT", "")
 
     def get_execution_context(self, request: HttpRequest) -> ExecutionContext:
-        data = self.parse_body(request)
+        try:
+            data = self.parse_body(request)
+        except json.decoder.JSONDecodeError:
+            raise SuspiciousOperation("Unable to parse request body as JSON")
 
         try:
             query = data["query"]
@@ -87,13 +98,29 @@ class BaseView(View):
 
         return response
 
+    def _create_response(
+        self, response_data: GraphQLHTTPResponse, sub_response: HttpResponse
+    ) -> JsonResponse:
+        response = JsonResponse(response_data)
+
+        for name, value in sub_response.items():
+            response[name] = value
+
+        if sub_response.status_code is not None:
+            response.status_code = sub_response.status_code
+
+        for name, value in sub_response.cookies.items():
+            response.cookies[name] = value
+
+        return response
+
 
 class GraphQLView(BaseView):
     def get_root_value(self, request: HttpRequest) -> Any:
         return None
 
-    def get_context(self, request: HttpRequest) -> Any:
-        return StrawberryDjangoContext(request)
+    def get_context(self, request: HttpRequest, response: HttpResponse) -> Any:
+        return StrawberryDjangoContext(request=request, response=response)
 
     def process_result(
         self, request: HttpRequest, result: ExecutionResult
@@ -111,7 +138,9 @@ class GraphQLView(BaseView):
             return self._render_graphiql(request)
 
         operation_context = self.get_execution_context(request)
-        context = self.get_context(request)
+
+        sub_response = TemporalHttpResponse()
+        context = self.get_context(request, response=sub_response)
 
         result = self.schema.execute_sync(
             operation_context.query,
@@ -123,7 +152,9 @@ class GraphQLView(BaseView):
 
         response_data = self.process_result(request=request, result=result)
 
-        return JsonResponse(response_data)
+        return self._create_response(
+            response_data=response_data, sub_response=sub_response
+        )
 
 
 class AsyncGraphQLView(BaseView):
@@ -147,7 +178,8 @@ class AsyncGraphQLView(BaseView):
             return self._render_graphiql(request)
 
         operation_context = self.get_execution_context(request)
-        context = await self.get_context(request)
+        sub_response = TemporalHttpResponse()
+        context = await self.get_context(request, response=sub_response)
         root_value = await self.get_root_value(request)
 
         result = await self.schema.execute(
@@ -160,13 +192,15 @@ class AsyncGraphQLView(BaseView):
 
         response_data = await self.process_result(request=request, result=result)
 
-        return JsonResponse(response_data)
+        return self._create_response(
+            response_data=response_data, sub_response=sub_response
+        )
 
     async def get_root_value(self, request: HttpRequest) -> Any:
         return None
 
-    async def get_context(self, request: HttpRequest) -> Any:
-        return {"request": request}
+    async def get_context(self, request: HttpRequest, response: HttpResponse) -> Any:
+        return StrawberryDjangoContext(request=request, response=response)
 
     async def process_result(
         self, request: HttpRequest, result: ExecutionResult
