@@ -1,9 +1,11 @@
 from typing import Any, Dict, List, Optional
 
-from graphql.error import format_error as format_graphql_error
-from strawberry.schema import ExecutionResult
 from typing_extensions import TypedDict
 
+from graphql.error import format_error as format_graphql_error
+
+from strawberry.types import ExecutionResult
+
 
 class GraphQLHTTPResponse(TypedDict, total=False):
     data: Optional[Dict[str, Any]]
