@@ -1,4 +1,4 @@
-from typing import Any, Callable, Dict, Type, Union, cast
+from typing import Any, Callable, Dict, Type, cast
 
 from graphql import (
     GraphQLArgument,
@@ -24,8 +24,7 @@ from graphql import (
 from strawberry.arguments import UNSET
 from strawberry.directive import DirectiveDefinition
 from strawberry.enum import EnumDefinition, EnumValue
-from strawberry.field import FieldDefinition
-from strawberry.resolvers import get_resolver
+from strawberry.field import StrawberryField
 from strawberry.scalars import is_scalar
 from strawberry.types.types import ArgumentDefinition, TypeDefinition, undefined
 from strawberry.union import StrawberryUnion
@@ -34,30 +33,47 @@ from .types.concrete_type import ConcreteType
 from .types.scalar import get_scalar_type
 
 
-FIELD_ARGUMENT_TYPE = Union[FieldDefinition, ArgumentDefinition]
-
-
 class GraphQLCoreConverter:
     # TODO: Make abstract
 
     def __init__(self):
         self.type_map: Dict[str, ConcreteType] = {}
 
-    def get_graphql_type_field(self, field: FIELD_ARGUMENT_TYPE) -> GraphQLType:
+    def get_graphql_type_argument(self, argument: ArgumentDefinition) -> GraphQLType:
         # TODO: Completely replace with get_graphql_type
 
         graphql_type: GraphQLType
 
-        if _is_list(field):
-            graphql_type = self.from_list(field)
-        elif _is_union(field):
+        if argument.is_list:
+            graphql_type = self.from_list_argument(argument)
+        elif argument.is_union:
+            assert isinstance(argument.type, StrawberryUnion)  # For mypy
+            graphql_type = self.from_union(argument.type)
+        else:
+            graphql_type = self.get_graphql_type(argument.type)
+
+        # TODO: Abstract this somehow. Logic is tricky
+        if not argument.is_optional:
+            graphql_type = cast(GraphQLNullableType, graphql_type)
+            graphql_type = GraphQLNonNull(graphql_type)
+
+        return graphql_type
+
+    def get_graphql_type_field(self, field: StrawberryField) -> GraphQLType:
+        # TODO: Completely replace with get_graphql_type
+
+        graphql_type: GraphQLType
+
+        if field.is_list:
+            graphql_type = self.from_list_field(field)
+        elif field.is_union:
             assert isinstance(field.type, StrawberryUnion)  # For mypy
             graphql_type = self.from_union(field.type)
         else:
             graphql_type = self.get_graphql_type(field.type)
 
         # TODO: Abstract this somehow. Logic is tricky
-        if not _is_optional(field):
+        if not field.is_optional:
             graphql_type = cast(GraphQLNullableType, graphql_type)
             graphql_type = GraphQLNonNull(graphql_type)
 
@@ -85,7 +101,7 @@ class GraphQLCoreConverter:
             Undefined if argument.default_value is undefined else argument.default_value
         )
 
-        argument_type = self.get_graphql_type_field(argument)
+        argument_type = self.get_graphql_type_argument(argument)
         argument_type = cast(GraphQLInputType, argument_type)
 
         return GraphQLArgument(
@@ -133,7 +149,7 @@ class GraphQLCoreConverter:
             description=directive.description,
         )
 
-    def from_field(self, field: FieldDefinition) -> GraphQLField:
+    def from_field(self, field: StrawberryField) -> GraphQLField:
 
         field_type = self.get_graphql_type_field(field)
         field_type = cast(GraphQLOutputType, field_type)
@@ -159,7 +175,7 @@ class GraphQLCoreConverter:
             deprecation_reason=field.deprecation_reason,
         )
 
-    def from_input_field(self, field: FieldDefinition) -> GraphQLInputField:
+    def from_input_field(self, field: StrawberryField) -> GraphQLInputField:
         if field.default_value in [undefined, UNSET]:
             default_value = Undefined
         else:
@@ -184,8 +200,8 @@ class GraphQLCoreConverter:
         def get_graphql_fields() -> Dict[str, GraphQLInputField]:
             graphql_fields = {}
             for field in type_definition.fields:
-                assert field.name is not None
-                graphql_fields[field.name] = self.from_input_field(field)
+                assert field.graphql_name is not None
+                graphql_fields[field.graphql_name] = self.from_input_field(field)
             return graphql_fields
 
         graphql_object_type = GraphQLInputObjectType(
@@ -212,8 +228,8 @@ class GraphQLCoreConverter:
         def get_graphql_fields() -> Dict[str, GraphQLField]:
             graphql_fields = {}
             for field in interface.fields:
-                assert field.name is not None
-                graphql_fields[field.name] = self.from_field(field)
+                assert field.graphql_name is not None
+                graphql_fields[field.graphql_name] = self.from_field(field)
             return graphql_fields
 
         graphql_interface = GraphQLInterfaceType(
@@ -229,7 +245,13 @@ class GraphQLCoreConverter:
 
         return graphql_interface
 
-    def from_list(self, list_: FIELD_ARGUMENT_TYPE) -> GraphQLList:
+    def from_list_argument(self, list_: ArgumentDefinition) -> GraphQLList:
+        assert list_.child is not None
+        of_type = self.get_graphql_type_argument(list_.child)
+
+        return GraphQLList(of_type)
+
+    def from_list_field(self, list_: StrawberryField) -> GraphQLList:
         assert list_.child is not None
         of_type = self.get_graphql_type_field(list_.child)
 
@@ -257,8 +279,8 @@ class GraphQLCoreConverter:
         def get_graphql_fields() -> Dict[str, GraphQLField]:
             graphql_fields = {}
             for field in type_definition.fields:
-                assert field.name is not None
-                graphql_fields[field.name] = self.from_field(field)
+                assert field.graphql_name is not None
+                graphql_fields[field.graphql_name] = self.from_field(field)
             return graphql_fields
 
         graphql_object_type = GraphQLObjectType(
@@ -275,8 +297,8 @@ class GraphQLCoreConverter:
 
         return graphql_object_type
 
-    def from_resolver(self, field: FieldDefinition) -> Callable:
-        return get_resolver(field)
+    def from_resolver(self, field: StrawberryField) -> Callable:
+        return field.get_wrapped_resolver()
 
     def from_scalar(self, scalar: Type) -> GraphQLScalarType:
         return get_scalar_type(scalar, self.type_map)
@@ -314,21 +336,6 @@ class GraphQLCoreConverter:
 ################################################################################
 
 
-def _is_list(field: FIELD_ARGUMENT_TYPE) -> bool:
-    # isinstance(type_, StrawberryList)  # noqa: E800
-    return field.is_list
-
-
-def _is_optional(field: FIELD_ARGUMENT_TYPE) -> bool:
-    # isinstance(type_, StrawberryOptional)  # noqa: E800
-    return field.is_optional
-
-
-def _is_union(field: FIELD_ARGUMENT_TYPE) -> bool:
-    # isinstance(type_, StrawberryUnion)  # noqa: E800
-    return field.is_union
-
-
 def _is_scalar(type_: Type) -> bool:
     # isinstance(type_, StrawberryScalar)  # noqa: E800
     return is_scalar(type_)
