@@ -1,12 +1,11 @@
 import dataclasses
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Type, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union
 
-from strawberry.permission import BasePermission
 from strawberry.union import StrawberryUnion
 
 
 if TYPE_CHECKING:
-    from strawberry.types.fields.resolver import StrawberryResolver
+    from strawberry.field import StrawberryField
 
 undefined = object()
 
@@ -28,14 +27,16 @@ class TypeDefinition:
     federation: FederationTypeParams
     interfaces: List["TypeDefinition"]
 
-    _fields: List["FieldDefinition"]
+    _fields: List["StrawberryField"]
     _type_params: Dict[str, Type] = dataclasses.field(default_factory=dict, init=False)
 
-    def get_field(self, name: str) -> Optional["FieldDefinition"]:
-        return next((field for field in self.fields if field.name == name), None)
+    def get_field(self, name: str) -> Optional["StrawberryField"]:
+        return next(
+            (field for field in self.fields if field.graphql_name == name), None
+        )
 
     @property
-    def fields(self) -> List["FieldDefinition"]:
+    def fields(self) -> List["StrawberryField"]:
         from .type_resolver import _resolve_types
 
         return _resolve_types(self._fields)
@@ -54,7 +55,7 @@ class TypeDefinition:
 class ArgumentDefinition:
     name: Optional[str] = None
     origin_name: Optional[str] = None
-    type: Optional[Type] = None
+    type: Optional[Union[Type, StrawberryUnion]] = None
     origin: Optional[Type] = None
     child: Optional["ArgumentDefinition"] = None
     is_subscription: bool = False
@@ -71,28 +72,3 @@ class FederationFieldParams:
     provides: List[str] = dataclasses.field(default_factory=list)
     requires: List[str] = dataclasses.field(default_factory=list)
     external: bool = False
-
-
-@dataclasses.dataclass
-class FieldDefinition:
-    name: Optional[str]
-    origin_name: Optional[str]
-    type: Optional[Union[Type, StrawberryUnion]]
-    origin: Optional[Union[Type, Callable]] = None
-    child: Optional["FieldDefinition"] = None
-    is_subscription: bool = False
-    is_optional: bool = False
-    is_child_optional: bool = False
-    is_list: bool = False
-    is_union: bool = False
-    federation: FederationFieldParams = dataclasses.field(
-        default_factory=FederationFieldParams
-    )
-    arguments: List[ArgumentDefinition] = dataclasses.field(default_factory=list)
-    description: Optional[str] = None
-    base_resolver: Optional["StrawberryResolver"] = None
-    permission_classes: List[Type[BasePermission]] = dataclasses.field(
-        default_factory=list
-    )
-    default_value: Any = undefined
-    deprecation_reason: Optional[str] = None
