@@ -1,6 +1,7 @@
 import datetime
 import json
-import typing
+from json import JSONEncoder
+from typing import Any, Dict
 
 from pygments import highlight, lexers
 from pygments.formatters import Terminal256Formatter
@@ -8,9 +9,14 @@ from pygments.formatters import Terminal256Formatter
 from .graphql_lexer import GraphQLLexer
 
 
+class StrawberryJSONEncoder(JSONEncoder):
+    def default(self, o: Any) -> Any:
+        return repr(o)
+
+
 def pretty_print_graphql_operation(
-    operation_name: str, query: str, variables: typing.Dict["str", typing.Any]
-):  # pragma: no cover
+    operation_name: str, query: str, variables: Dict["str", Any]
+):
     """Pretty print a GraphQL operation using pygments.
 
     Won't print introspection operation to prevent noise in the output."""
@@ -24,6 +30,6 @@ def pretty_print_graphql_operation(
     print(highlight(query, GraphQLLexer(), Terminal256Formatter()))
 
     if variables:
-        variables_json = json.dumps(variables, indent=4)
+        variables_json = json.dumps(variables, indent=4, cls=StrawberryJSONEncoder)
 
         print(highlight(variables_json, lexers.JsonLexer(), Terminal256Formatter()))
